<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en">
<context>
    <name>AuthDialog</name>
    <message>
        <location filename="../AuthDialog.cpp" line="72"/>
        <source>Finger moved too fast, please do not lift until prompted</source>
        <translation>Finger moved too fast, please do not lift until prompted</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="74"/>
        <source>Verification failed, two chances left</source>
        <translation>Verification failed, two chances left</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="90"/>
        <location filename="../AuthDialog.cpp" line="327"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirm</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="159"/>
        <source>Expired</source>
        <translation>Expired</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="248"/>
        <source>Unavailable</source>
        <translation>Unavailable</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="250"/>
        <source>The password of this user has expired. Please authenticate using another user account or change the password and try again.</source>
        <translation>The password of this user has expired. Please authenticate using another user account or change the password and try again.</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="287"/>
        <source>Locked, please try again later</source>
        <translation>Locked, please try again later</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="289"/>
        <source>Wrong password</source>
        <translation>Wrong password</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="326"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel</translation>
    </message>
</context>
</TS>